# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .finish_reason import FinishReason
from .generated_text_data import GeneratedTextData
from .token_usage import TokenUsage


class NonStreamAnalyzeResponse(UniversalBaseModel):
    """
    When the value of the `stream` parameter is set to `false`, the response is as follows:
    """

    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Unique identifier of the response.
    """

    data: typing.Optional[GeneratedTextData] = None
    finish_reason: typing.Optional[FinishReason] = None
    usage: typing.Optional[TokenUsage] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
