# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from .hls_object import HlsObject
from .indexed_asset import IndexedAsset
from .indexed_asset_detailed_embedding import IndexedAssetDetailedEmbedding
from .transcription_data import TranscriptionData


class IndexedAssetDetailed(IndexedAsset):
    user_metadata: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    User-generated metadata about the indexed asset.
    """

    hls: typing.Optional[HlsObject] = None
    embedding: typing.Optional[IndexedAssetDetailedEmbedding] = pydantic.Field(default=None)
    """
    Contains the embedding and the associated information. The platform returns this field when the `embedding_option` parameter is specified in the request.
    """

    transcription: typing.Optional[TranscriptionData] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
