# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ....types.analyze_task_response import AnalyzeTaskResponse
from ....types.page_info import PageInfo


class TasksListResponse(UniversalBaseModel):
    data: typing.List[AnalyzeTaskResponse] = pydantic.Field()
    """
    An array that contains up to `page_limit` analysis tasks.
    """

    page_info: PageInfo

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
