# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .summarize_highlight_result_highlights_item import SummarizeHighlightResultHighlightsItem
from .summarize_highlight_result_summarize_type import SummarizeHighlightResultSummarizeType
from .token_usage import TokenUsage


class SummarizeHighlightResult(UniversalBaseModel):
    """
    An object that represents the response from a summarize highlight operation.
    """

    summarize_type: SummarizeHighlightResultSummarizeType = pydantic.Field()
    """
    The type of summarize response.
    """

    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Unique identifier of the response.
    """

    highlights: typing.Optional[typing.List[SummarizeHighlightResultHighlightsItem]] = pydantic.Field(default=None)
    """
    An array that contains the highlights.
    """

    usage: typing.Optional[TokenUsage] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
