# This file was auto-generated by Fern from our API Definition.

import typing

VideosRetrieveRequestEmbeddingOptionItem = typing.Union[
    typing.Literal["visual", "audio", "transcription", "visual-text"], typing.Any
]
