# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class VideosRetrieveResponseSystemMetadata(UniversalBaseModel):
    """
    System-generated metadata about the video.
    """

    duration: typing.Optional[float] = None
    filename: typing.Optional[str] = None
    fps: typing.Optional[float] = None
    height: typing.Optional[int] = None
    width: typing.Optional[int] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
