# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .indexed_asset_detailed_embedding_video_embedding import IndexedAssetDetailedEmbeddingVideoEmbedding


class IndexedAssetDetailedEmbedding(UniversalBaseModel):
    """
    Contains the embedding and the associated information. The platform returns this field when the `embedding_option` parameter is specified in the request.
    """

    model_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the video understanding model used to create the embedding.
    """

    video_embedding: typing.Optional[IndexedAssetDetailedEmbeddingVideoEmbedding] = pydantic.Field(default=None)
    """
    An object that contains the embeddings.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
