# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .create_embeddings_request_input_type import CreateEmbeddingsRequestInputType
from .create_embeddings_request_model_name import CreateEmbeddingsRequestModelName

__all__ = ["CreateEmbeddingsRequestInputType", "CreateEmbeddingsRequestModelName"]
