# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ....types.video_segment import VideoSegment


class VideosRetrieveResponseEmbeddingVideoEmbedding(UniversalBaseModel):
    """
    An object that contains the embeddings.
    """

    segments: typing.Optional[typing.List[VideoSegment]] = pydantic.Field(default=None)
    """
    An array of objects that contains the embeddings for each individual segment.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
