# This file was auto-generated by Fern from our API Definition.

import typing

CreateEmbeddingsRequestInputType = typing.Union[
    typing.Literal["text", "image", "text_image", "audio", "video", "multi_input"], typing.Any
]
