# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class Url(UniversalBaseModel):
    """
    Provide the video via a URL.
    """

    url: str = pydantic.Field()
    """
    The publicly accessible URL of the video file.
    
    Use direct links to raw media files. Video hosting platforms and cloud storage sharing links are not supported.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
