# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .video_segmentation_dynamic_dynamic import VideoSegmentationDynamicDynamic
from .video_segmentation_fixed_fixed import VideoSegmentationFixedFixed


class VideoSegmentation_Dynamic(UniversalBaseModel):
    """
    Specifies how the platform divides the video into segments.
    """

    strategy: typing.Literal["dynamic"] = "dynamic"
    dynamic: VideoSegmentationDynamicDynamic

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class VideoSegmentation_Fixed(UniversalBaseModel):
    """
    Specifies how the platform divides the video into segments.
    """

    strategy: typing.Literal["fixed"] = "fixed"
    fixed: VideoSegmentationFixedFixed

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


VideoSegmentation = typing.Union[VideoSegmentation_Dynamic, VideoSegmentation_Fixed]
