# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .finish_reason import FinishReason
from .stream_end_response_metadata import StreamEndResponseMetadata


class StreamEndResponse(UniversalBaseModel):
    """
    Indicates the end of the stream.
    """

    finish_reason: typing.Optional[FinishReason] = None
    metadata: typing.Optional[StreamEndResponseMetadata] = pydantic.Field(default=None)
    """
    An object containing metadata about the stream.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
