# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from .....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....core.serialization import FieldMetadata
from .....types.embedding_data import EmbeddingData
from .tasks_create_response_status import TasksCreateResponseStatus


class TasksCreateResponse(UniversalBaseModel):
    id: typing_extensions.Annotated[str, FieldMetadata(alias="_id")] = pydantic.Field()
    """
    The unique identifier of the embedding task
    """

    status: TasksCreateResponseStatus = pydantic.Field()
    """
    The initial status of the embedding task.
    """

    data: typing.Optional[typing.List[EmbeddingData]] = pydantic.Field(default=None)
    """
    An array of embedding results when `status` is `ready`, or `null` when `status` is `processing` or `failed`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
