# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from .base_embedding_metadata import BaseEmbeddingMetadata


class AudioEmbeddingMetadata(BaseEmbeddingMetadata):
    """
    An object containing metadata associated with the embedding.
    """

    audio_embedding_options: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    The type of the embedding. It can take one of the following values: ['audio'] or ['transcription'].
    """

    audio_embedding_scopes: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    The scope you've specified in the request.
    """

    duration: typing.Optional[float] = pydantic.Field(default=None)
    """
    The total duration of the audio in seconds.
    """

    start_offset_sec: typing.Optional[float] = pydantic.Field(default=None)
    """
    The start offset in seconds from the beginning of the audio where processing should begin.
    """

    end_offset_sec: typing.Optional[float] = pydantic.Field(default=None)
    """
    The end offset in seconds from the beginning of the audio where processing should end.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
