# This file was auto-generated by Fern from our API Definition.

import typing

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.request_options import RequestOptions
from .raw_client import AsyncRawTransfersClient, RawTransfersClient


class TransfersClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawTransfersClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawTransfersClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawTransfersClient
        """
        return self._raw_client

    def create(self, integration_id: str, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        Parameters
        ----------
        integration_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from twelvelabs import TwelveLabs

        client = TwelveLabs(
            api_key="YOUR_API_KEY",
        )
        client.tasks.transfers.create(
            integration_id="integration-id",
        )
        """
        _response = self._raw_client.create(integration_id, request_options=request_options)
        return _response.data

    def get_status(self, integration_id: str, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        Parameters
        ----------
        integration_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from twelvelabs import TwelveLabs

        client = TwelveLabs(
            api_key="YOUR_API_KEY",
        )
        client.tasks.transfers.get_status(
            integration_id="integration-id",
        )
        """
        _response = self._raw_client.get_status(integration_id, request_options=request_options)
        return _response.data

    def get_logs(self, integration_id: str, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        Parameters
        ----------
        integration_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from twelvelabs import TwelveLabs

        client = TwelveLabs(
            api_key="YOUR_API_KEY",
        )
        client.tasks.transfers.get_logs(
            integration_id="integration-id",
        )
        """
        _response = self._raw_client.get_logs(integration_id, request_options=request_options)
        return _response.data


class AsyncTransfersClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawTransfersClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawTransfersClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawTransfersClient
        """
        return self._raw_client

    async def create(self, integration_id: str, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        Parameters
        ----------
        integration_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from twelvelabs import AsyncTwelveLabs

        client = AsyncTwelveLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.tasks.transfers.create(
                integration_id="integration-id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(integration_id, request_options=request_options)
        return _response.data

    async def get_status(self, integration_id: str, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        Parameters
        ----------
        integration_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from twelvelabs import AsyncTwelveLabs

        client = AsyncTwelveLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.tasks.transfers.get_status(
                integration_id="integration-id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_status(integration_id, request_options=request_options)
        return _response.data

    async def get_logs(self, integration_id: str, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        Parameters
        ----------
        integration_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from twelvelabs import AsyncTwelveLabs

        client = AsyncTwelveLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.tasks.transfers.get_logs(
                integration_id="integration-id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_logs(integration_id, request_options=request_options)
        return _response.data
