# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .summarize_summary_result_summarize_type import SummarizeSummaryResultSummarizeType
from .token_usage import TokenUsage


class SummarizeSummaryResult(UniversalBaseModel):
    """
    An object that represents the response from a summarize summary operation.
    """

    summarize_type: SummarizeSummaryResultSummarizeType = pydantic.Field()
    """
    The type of summarize response.
    """

    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Unique identifier of the response.
    """

    summary: typing.Optional[str] = pydantic.Field(default=None)
    """
    A brief report of the main points of the video.
    """

    usage: typing.Optional[TokenUsage] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
