# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .video_segmentation_dynamic_dynamic import VideoSegmentationDynamicDynamic


class VideoSegmentationDynamic(UniversalBaseModel):
    dynamic: VideoSegmentationDynamicDynamic = pydantic.Field()
    """
    Configuration for dynamic segmentation. This object is required when `strategy` is `dynamic`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
