# This file was auto-generated by Fern from our API Definition.

import typing

TasksListRequestStatusItem = typing.Union[
    typing.Literal["ready", "uploading", "validating", "pending", "queued", "indexing", "failed"], typing.Any
]
