# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from .....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....types.media_embedding_task import MediaEmbeddingTask
from .tasks_list_response_page_info import TasksListResponsePageInfo


class TasksListResponse(UniversalBaseModel):
    data: typing.Optional[typing.List[MediaEmbeddingTask]] = pydantic.Field(default=None)
    """
    An array that contains up to `page_limit` embedding tasks.
    """

    page_info: typing.Optional[TasksListResponsePageInfo] = pydantic.Field(default=None)
    """
    An object that provides information about pagination.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
