# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AnalyzeTaskWebhookInfo(UniversalBaseModel):
    """
    The delivery status of a webhook endpoint.
    """

    url: str = pydantic.Field()
    """
    The URL of the webhook endpoint that received the delivery.
    """

    delivered: bool = pydantic.Field()
    """
    Indicates whether the platform successfully delivered the webhook.
    """

    attempts: int = pydantic.Field()
    """
    The total number of delivery attempts for this URL.
    """

    last_error: typing.Optional[str] = pydantic.Field(default=None)
    """
    The error message from the last failed delivery attempt. This field appears only when `delivered` is `false`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
