# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ImportLogFailedFilesItem(UniversalBaseModel):
    filename: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the video file that failed to import.
    """

    error_message: typing.Optional[str] = pydantic.Field(default=None)
    """
    A human-readable error message.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
