# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .audio_segmentation_fixed import AudioSegmentationFixed
from .audio_segmentation_strategy import AudioSegmentationStrategy


class AudioSegmentation(UniversalBaseModel):
    """
    Specifies how the platform divides the audio into segments.
    """

    strategy: AudioSegmentationStrategy
    fixed: AudioSegmentationFixed = pydantic.Field()
    """
    Configuration for fixed segmentation.
    
    This object is required when the `strategy` field is `fixed`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
