# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from .base_segment import BaseSegment
from .end_offset_sec import EndOffsetSec
from .start_offset_sec import StartOffsetSec


class AudioSegment(BaseSegment):
    """
    An object that contains the audio embedding and its start time.
    """

    start_offset_sec: typing.Optional[StartOffsetSec] = None
    end_offset_sec: typing.Optional[EndOffsetSec] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
