# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .create_asset_upload_request_type import CreateAssetUploadRequestType

__all__ = ["CreateAssetUploadRequestType"]
