# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .created_at import CreatedAt
from .expires_at import ExpiresAt
from .multipart_upload_status_type import MultipartUploadStatusType


class IncompleteUploadSummary(UniversalBaseModel):
    upload_id: str = pydantic.Field()
    """
    The unique identifier of your upload session.
    """

    status: MultipartUploadStatusType
    total_size: int = pydantic.Field()
    """
    Total size of the file in bytes.
    """

    chunk_size: int = pydantic.Field()
    """
    The size of each chunk in bytes.
    """

    total_chunks: int = pydantic.Field()
    """
    The total number of chunks in this upload session.
    """

    created_at: typing.Optional[CreatedAt] = None
    expires_at: typing.Optional[ExpiresAt] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
