# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class BadRequestErrorBody(UniversalBaseModel):
    code: typing.Optional[str] = pydantic.Field(default=None)
    """
    A string representing the code associated with the error. See the [Error codes](/v1.3/api-reference/error-codes) page for details.
    """

    message: typing.Optional[str] = pydantic.Field(default=None)
    """
    A human-readable string describing the error, intended to be suitable for display in a user interface.
    """

    docs_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    The URL of the relevant documentation page.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
