# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class EntitiesCreateBulkRequestEntitiesItem(UniversalBaseModel):
    name: str = pydantic.Field()
    """
    The name of the entity.
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional description of the entity.
    """

    metadata: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Optional metadata for the entity, provided as key-value pairs.
    """

    asset_ids: typing.List[str] = pydantic.Field()
    """
    An array of asset IDs to associate with the entity. At least one asset ID is required.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
