# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from .entity import Entity


class InternalEntity(Entity):
    """
    An object that extends the Entity schema with additional collection information.
    """

    entity_collection_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The unique identifier of the entity collection the entity belongs to.
    """

    entity_collection_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the entity collection the entity belongs to.
    """

    asset_urls: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    An array of URLs for the assets associated with the entity.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
